# Kyklop
## Introduction

Kyklop is a tool for detection, tracking, and analysis of tropical cyclones in weather data.

## License
Kyklop is licensed under the MIT License. [View the license file.](./LICENSE)
